<?php

namespace Drupal\commerce_sage_payments\Configure;

use Drupal\commerce_transaction\Entity\TransactionTypeInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;

/**
 * The default installer for the Commerce Sage Payments module.
 */
class Installer implements InstallerInterface {

  /**
   * The transaction type storage.
   *
   * @var \Drupal\Core\Config\Entity\ConfigEntityStorageInterface
   */
  protected $transactionTypeStorage;

  /**
   * Constructs a new Installer object.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity type manager.
   */
  public function __construct(EntityTypeManagerInterface $entity_type_manager) {
    $this->transactionTypeStorage = $entity_type_manager
      ->getStorage('commerce_transaction_type');
  }

  /**
   * {@inheritdoc}
   */
  public function install() {
    $this->installTransactionTypes();
  }

  /**
   * {@inheritdoc}
   */
  public function installTransactionTypes() {
    if (!$this->transactionTypeStorage->load('sage_payments_charge')) {
      $charge_type = $this->transactionTypeStorage->create([
        'id' => 'sage_payments_charge',
        'label' => 'Charge',
        'description' => 'The charge transaction type for Sage Payments.',
        'type' => TransactionTypeInterface::TYPE_CHARGE,
        'workflow' => 'transaction_sage_payments',
      ]);
      $this->transactionTypeStorage->save($charge_type);
    }

    if (!$this->transactionTypeStorage->load('sage_payments_refund')) {
      $refund_type = $this->transactionTypeStorage->create([
        'id' => 'sage_payments_refund',
        'label' => 'Refund',
        'description' => 'The refund transaction type for Sage Payments.',
        'type' => TransactionTypeInterface::TYPE_REFUND,
        'workflow' => 'transaction_sage_payments',
      ]);
      $this->transactionTypeStorage->save($refund_type);
    }
  }

}
