<?php

namespace Drupal\commerce_sage_payments\Configure;

/**
 * Installs configuration as expected by Sage Payments functionality.
 *
 * It can be used in install, update and uninstall functions, or in custom
 * functions/commands to ensure that all required configuration is
 * installed. The latter may be useful for resolving problematic installations.
 *
 * Note that the expected behavior of the Installer is to install expected
 * configuration if it doesn't exist, but to not throw exceptions if it is
 * already installed. That way, it can be safely run again as additions are
 * being made without errors on previously installed configuration. Uninstalling
 * is different though; exceptions should be thrown when trying to uninstall
 * something that is not installed.
 */
interface InstallerInterface {

  /**
   * Installs all required configuration.
   *
   * It includes:
   *   - Installing the Charge and Refund transaction types.
   */
  public function install();

  /**
   * Installs the transaction types required by Sage Payments.
   */
  public function installTransactionTypes();

}
