<?php

namespace Drupal\commerce_sage_payments\Controller;

use Drupal\Core\Access\AccessResult;
use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
use Drupal\Core\Session\AccountInterface;
use Drupal\Core\Routing\RouteMatchInterface;

use Symfony\Component\HttpFoundation\RequestStack;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides checkout endpoints and access checks.
 */
class Checkout implements ContainerInjectionInterface {

  /**
   * The request stack.
   *
   * @var \Symfony\Component\HttpFoundation\RequestStack
   */
  protected $requestStack;

  /**
   * Constructs a new Checkout object.
   *
   * @param \Symfony\Component\HttpFoundation\RequestStack $request_stack
   *   The request stack.
   */
  public function __construct(RequestStack $request_stack) {
    $this->requestStack = $request_stack;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('request_stack')
    );
  }

  /**
   * Checks access to the SEVD return endpoint.
   *
   * @param \Drupal\Core\Routing\RouteMatchInterface $route_match
   *   The route match.
   * @param \Drupal\Core\Session\AccountInterface $account
   *   The current user account.
   *
   * @return \Drupal\Core\Access\AccessResult
   *   The access result.
   */
  public function checkAccess(
    RouteMatchInterface $route_match,
    AccountInterface $account
  ) {
    $headers = $this->requestStack->getMasterRequest()->headers->all();
    $origin_url = 'https://www.sageexchange.com';
    $authorized = TRUE;

    // We only allow requests coming from Sage Exchange.
    foreach (['origin', 'referer'] as $header) {
      if (empty($headers[$header])) {
        $authorized = FALSE;
        break;
      }

      $header_array = array_map(
        function ($item) {
          return trim($item, '//');
        },
        $headers[$header]
      );
      $index = array_search($origin_url, $header_array);

      if ($index === FALSE) {
        $authorized = FALSE;
      }
    }

    return AccessResult::allowedIf($authorized);
  }

}
